@@ -91,65 +91,47 @@ namespace Model
 
 
     /**
-     * 
-            <p>The Tag keys to delete.</p>
-         
+     * <p>The Tag keys to delete</p>
      */
     inline const Aws::Vector<Aws::String>& GetTagKeys() const{ return m_tagKeys; }
 
     /**
-     * 
-            <p>The Tag keys to delete.</p>
-         
+     * <p>The Tag keys to delete</p>
      */
     inline bool TagKeysHasBeenSet() const { return m_tagKeysHasBeenSet; }
 
     /**
-     * 
-            <p>The Tag keys to delete.</p>
-         
+     * <p>The Tag keys to delete</p>
      */
     inline void SetTagKeys(const Aws::Vector<Aws::String>& value) { m_tagKeysHasBeenSet = true; m_tagKeys = value; }
 
     /**
-     * 
-            <p>The Tag keys to delete.</p>
-         
+     * <p>The Tag keys to delete</p>
      */
     inline void SetTagKeys(Aws::Vector<Aws::String>&& value) { m_tagKeysHasBeenSet = true; m_tagKeys = std::move(value); }
 
     /**
-     * 
-            <p>The Tag keys to delete.</p>
-         
+     * <p>The Tag keys to delete</p>
      */
     inline UntagResourceRequest& WithTagKeys(const Aws::Vector<Aws::String>& value) { SetTagKeys(value); return *this;}
 
     /**
-     * 
-            <p>The Tag keys to delete.</p>
-         
+     * <p>The Tag keys to delete</p>
      */
     inline UntagResourceRequest& WithTagKeys(Aws::Vector<Aws::String>&& value) { SetTagKeys(std::move(value)); return *this;}
 
     /**
-     * 
-            <p>The Tag keys to delete.</p>
-         
+     * <p>The Tag keys to delete</p>
      */
     inline UntagResourceRequest& AddTagKeys(const Aws::String& value) { m_tagKeysHasBeenSet = true; m_tagKeys.push_back(value); return *this; }
 
     /**
-     * 
-            <p>The Tag keys to delete.</p>
-         
+     * <p>The Tag keys to delete</p>
      */
     inline UntagResourceRequest& AddTagKeys(Aws::String&& value) { m_tagKeysHasBeenSet = true; m_tagKeys.push_back(std::move(value)); return *this; }
 
     /**
-     * 
-            <p>The Tag keys to delete.</p>
-         
+     * <p>The Tag keys to delete</p>
      */
     inline UntagResourceRequest& AddTagKeys(const char* value) { m_tagKeysHasBeenSet = true; m_tagKeys.push_back(value); return *this; }
 
