@@ -481,6 +481,31 @@ namespace Model
      */
     inline GraphqlApi& AddAdditionalAuthenticationProviders(AdditionalAuthenticationProvider&& value) { m_additionalAuthenticationProvidersHasBeenSet = true; m_additionalAuthenticationProviders.push_back(std::move(value)); return *this; }
 
+
+    /**
+     * <p>A flag representing whether X-Ray tracing is enabled for this
+     * <code>GraphqlApi</code>.</p>
+     */
+    inline bool GetXrayEnabled() const{ return m_xrayEnabled; }
+
+    /**
+     * <p>A flag representing whether X-Ray tracing is enabled for this
+     * <code>GraphqlApi</code>.</p>
+     */
+    inline bool XrayEnabledHasBeenSet() const { return m_xrayEnabledHasBeenSet; }
+
+    /**
+     * <p>A flag representing whether X-Ray tracing is enabled for this
+     * <code>GraphqlApi</code>.</p>
+     */
+    inline void SetXrayEnabled(bool value) { m_xrayEnabledHasBeenSet = true; m_xrayEnabled = value; }
+
+    /**
+     * <p>A flag representing whether X-Ray tracing is enabled for this
+     * <code>GraphqlApi</code>.</p>
+     */
+    inline GraphqlApi& WithXrayEnabled(bool value) { SetXrayEnabled(value); return *this;}
+
   private:
 
     Aws::String m_name;
@@ -512,6 +537,9 @@ namespace Model
 
     Aws::Vector<AdditionalAuthenticationProvider> m_additionalAuthenticationProviders;
     bool m_additionalAuthenticationProvidersHasBeenSet;
+
+    bool m_xrayEnabled;
+    bool m_xrayEnabledHasBeenSet;
   };
 
 } // namespace Model
