@@ -229,6 +229,112 @@ namespace Model
      */
     inline AssociateVpcCidrBlockRequest& WithIpv6CidrBlockNetworkBorderGroup(const char* value) { SetIpv6CidrBlockNetworkBorderGroup(value); return *this;}
 
+
+    /**
+     * <p>The ID of an IPv6 address pool from which to allocate the IPv6 CIDR
+     * block.</p>
+     */
+    inline const Aws::String& GetIpv6Pool() const{ return m_ipv6Pool; }
+
+    /**
+     * <p>The ID of an IPv6 address pool from which to allocate the IPv6 CIDR
+     * block.</p>
+     */
+    inline bool Ipv6PoolHasBeenSet() const { return m_ipv6PoolHasBeenSet; }
+
+    /**
+     * <p>The ID of an IPv6 address pool from which to allocate the IPv6 CIDR
+     * block.</p>
+     */
+    inline void SetIpv6Pool(const Aws::String& value) { m_ipv6PoolHasBeenSet = true; m_ipv6Pool = value; }
+
+    /**
+     * <p>The ID of an IPv6 address pool from which to allocate the IPv6 CIDR
+     * block.</p>
+     */
+    inline void SetIpv6Pool(Aws::String&& value) { m_ipv6PoolHasBeenSet = true; m_ipv6Pool = std::move(value); }
+
+    /**
+     * <p>The ID of an IPv6 address pool from which to allocate the IPv6 CIDR
+     * block.</p>
+     */
+    inline void SetIpv6Pool(const char* value) { m_ipv6PoolHasBeenSet = true; m_ipv6Pool.assign(value); }
+
+    /**
+     * <p>The ID of an IPv6 address pool from which to allocate the IPv6 CIDR
+     * block.</p>
+     */
+    inline AssociateVpcCidrBlockRequest& WithIpv6Pool(const Aws::String& value) { SetIpv6Pool(value); return *this;}
+
+    /**
+     * <p>The ID of an IPv6 address pool from which to allocate the IPv6 CIDR
+     * block.</p>
+     */
+    inline AssociateVpcCidrBlockRequest& WithIpv6Pool(Aws::String&& value) { SetIpv6Pool(std::move(value)); return *this;}
+
+    /**
+     * <p>The ID of an IPv6 address pool from which to allocate the IPv6 CIDR
+     * block.</p>
+     */
+    inline AssociateVpcCidrBlockRequest& WithIpv6Pool(const char* value) { SetIpv6Pool(value); return *this;}
+
+
+    /**
+     * <p>An IPv6 CIDR block from the IPv6 address pool. You must also specify
+     * <code>Ipv6Pool</code> in the request.</p> <p>To let Amazon choose the IPv6 CIDR
+     * block for you, omit this parameter.</p>
+     */
+    inline const Aws::String& GetIpv6CidrBlock() const{ return m_ipv6CidrBlock; }
+
+    /**
+     * <p>An IPv6 CIDR block from the IPv6 address pool. You must also specify
+     * <code>Ipv6Pool</code> in the request.</p> <p>To let Amazon choose the IPv6 CIDR
+     * block for you, omit this parameter.</p>
+     */
+    inline bool Ipv6CidrBlockHasBeenSet() const { return m_ipv6CidrBlockHasBeenSet; }
+
+    /**
+     * <p>An IPv6 CIDR block from the IPv6 address pool. You must also specify
+     * <code>Ipv6Pool</code> in the request.</p> <p>To let Amazon choose the IPv6 CIDR
+     * block for you, omit this parameter.</p>
+     */
+    inline void SetIpv6CidrBlock(const Aws::String& value) { m_ipv6CidrBlockHasBeenSet = true; m_ipv6CidrBlock = value; }
+
+    /**
+     * <p>An IPv6 CIDR block from the IPv6 address pool. You must also specify
+     * <code>Ipv6Pool</code> in the request.</p> <p>To let Amazon choose the IPv6 CIDR
+     * block for you, omit this parameter.</p>
+     */
+    inline void SetIpv6CidrBlock(Aws::String&& value) { m_ipv6CidrBlockHasBeenSet = true; m_ipv6CidrBlock = std::move(value); }
+
+    /**
+     * <p>An IPv6 CIDR block from the IPv6 address pool. You must also specify
+     * <code>Ipv6Pool</code> in the request.</p> <p>To let Amazon choose the IPv6 CIDR
+     * block for you, omit this parameter.</p>
+     */
+    inline void SetIpv6CidrBlock(const char* value) { m_ipv6CidrBlockHasBeenSet = true; m_ipv6CidrBlock.assign(value); }
+
+    /**
+     * <p>An IPv6 CIDR block from the IPv6 address pool. You must also specify
+     * <code>Ipv6Pool</code> in the request.</p> <p>To let Amazon choose the IPv6 CIDR
+     * block for you, omit this parameter.</p>
+     */
+    inline AssociateVpcCidrBlockRequest& WithIpv6CidrBlock(const Aws::String& value) { SetIpv6CidrBlock(value); return *this;}
+
+    /**
+     * <p>An IPv6 CIDR block from the IPv6 address pool. You must also specify
+     * <code>Ipv6Pool</code> in the request.</p> <p>To let Amazon choose the IPv6 CIDR
+     * block for you, omit this parameter.</p>
+     */
+    inline AssociateVpcCidrBlockRequest& WithIpv6CidrBlock(Aws::String&& value) { SetIpv6CidrBlock(std::move(value)); return *this;}
+
+    /**
+     * <p>An IPv6 CIDR block from the IPv6 address pool. You must also specify
+     * <code>Ipv6Pool</code> in the request.</p> <p>To let Amazon choose the IPv6 CIDR
+     * block for you, omit this parameter.</p>
+     */
+    inline AssociateVpcCidrBlockRequest& WithIpv6CidrBlock(const char* value) { SetIpv6CidrBlock(value); return *this;}
+
   private:
 
     bool m_amazonProvidedIpv6CidrBlock;
@@ -242,6 +348,12 @@ namespace Model
 
     Aws::String m_ipv6CidrBlockNetworkBorderGroup;
     bool m_ipv6CidrBlockNetworkBorderGroupHasBeenSet;
+
+    Aws::String m_ipv6Pool;
+    bool m_ipv6PoolHasBeenSet;
+
+    Aws::String m_ipv6CidrBlock;
+    bool m_ipv6CidrBlockHasBeenSet;
   };
 
 } // namespace Model
