@@ -33,8 +33,11 @@ namespace Model
     Ec2LaunchTemplateNotFound,
     Ec2LaunchTemplateVersionMismatch,
     Ec2SubnetNotFound,
+    Ec2SubnetInvalidConfiguration,
     IamInstanceProfileNotFound,
+    IamLimitExceeded,
     IamNodeRoleNotFound,
+    NodeCreationFailure,
     AsgInstanceLaunchFailures,
     InstanceLimitExceeded,
     InsufficientFreeAddresses,
