@@ -330,6 +330,55 @@ namespace Model
     inline InstanceDetails& WithInstanceType(const char* value) { SetInstanceType(value); return *this;}
 
 
+    /**
+     * <p>The Amazon Resource Name (ARN) of the AWS Outpost. Only applicable to AWS
+     * Outposts instances.</p>
+     */
+    inline const Aws::String& GetOutpostArn() const{ return m_outpostArn; }
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the AWS Outpost. Only applicable to AWS
+     * Outposts instances.</p>
+     */
+    inline bool OutpostArnHasBeenSet() const { return m_outpostArnHasBeenSet; }
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the AWS Outpost. Only applicable to AWS
+     * Outposts instances.</p>
+     */
+    inline void SetOutpostArn(const Aws::String& value) { m_outpostArnHasBeenSet = true; m_outpostArn = value; }
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the AWS Outpost. Only applicable to AWS
+     * Outposts instances.</p>
+     */
+    inline void SetOutpostArn(Aws::String&& value) { m_outpostArnHasBeenSet = true; m_outpostArn = std::move(value); }
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the AWS Outpost. Only applicable to AWS
+     * Outposts instances.</p>
+     */
+    inline void SetOutpostArn(const char* value) { m_outpostArnHasBeenSet = true; m_outpostArn.assign(value); }
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the AWS Outpost. Only applicable to AWS
+     * Outposts instances.</p>
+     */
+    inline InstanceDetails& WithOutpostArn(const Aws::String& value) { SetOutpostArn(value); return *this;}
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the AWS Outpost. Only applicable to AWS
+     * Outposts instances.</p>
+     */
+    inline InstanceDetails& WithOutpostArn(Aws::String&& value) { SetOutpostArn(std::move(value)); return *this;}
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the AWS Outpost. Only applicable to AWS
+     * Outposts instances.</p>
+     */
+    inline InstanceDetails& WithOutpostArn(const char* value) { SetOutpostArn(value); return *this;}
+
+
     /**
      * <p>The launch time of the EC2 instance.</p>
      */
@@ -557,6 +606,9 @@ namespace Model
     Aws::String m_instanceType;
     bool m_instanceTypeHasBeenSet;
 
+    Aws::String m_outpostArn;
+    bool m_outpostArnHasBeenSet;
+
     Aws::String m_launchTime;
     bool m_launchTimeHasBeenSet;
 
