@@ -23,6 +23,7 @@
 #include <aws/kafka/model/EncryptionInfo.h>
 #include <aws/kafka/model/EnhancedMonitoring.h>
 #include <aws/kafka/model/OpenMonitoringInfo.h>
+#include <aws/kafka/model/LoggingInfo.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <utility>
 
@@ -439,6 +440,25 @@ namespace Model
     inline CreateClusterRequest& WithKafkaVersion(const char* value) { SetKafkaVersion(value); return *this;}
 
 
+    
+    inline const LoggingInfo& GetLoggingInfo() const{ return m_loggingInfo; }
+
+    
+    inline bool LoggingInfoHasBeenSet() const { return m_loggingInfoHasBeenSet; }
+
+    
+    inline void SetLoggingInfo(const LoggingInfo& value) { m_loggingInfoHasBeenSet = true; m_loggingInfo = value; }
+
+    
+    inline void SetLoggingInfo(LoggingInfo&& value) { m_loggingInfoHasBeenSet = true; m_loggingInfo = std::move(value); }
+
+    
+    inline CreateClusterRequest& WithLoggingInfo(const LoggingInfo& value) { SetLoggingInfo(value); return *this;}
+
+    
+    inline CreateClusterRequest& WithLoggingInfo(LoggingInfo&& value) { SetLoggingInfo(std::move(value)); return *this;}
+
+
     /**
      * 
             <p>The number of broker nodes in the cluster.</p>
@@ -585,6 +605,9 @@ namespace Model
     Aws::String m_kafkaVersion;
     bool m_kafkaVersionHasBeenSet;
 
+    LoggingInfo m_loggingInfo;
+    bool m_loggingInfoHasBeenSet;
+
     int m_numberOfBrokerNodes;
     bool m_numberOfBrokerNodesHasBeenSet;
 
