@@ -27,7 +27,8 @@ namespace Model
   {
     NOT_SET,
     restore_cluster,
-    recommend_node_config
+    recommend_node_config,
+    resize_cluster
   };
 
 namespace ActionTypeMapper
