@@ -19,8 +19,8 @@
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/sagemaker/model/HyperParameterTuningJobConfig.h>
 #include <aws/sagemaker/model/HyperParameterTrainingJobDefinition.h>
-#include <aws/sagemaker/model/HyperParameterTuningJobWarmStartConfig.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
+#include <aws/sagemaker/model/HyperParameterTuningJobWarmStartConfig.h>
 #include <aws/sagemaker/model/Tag.h>
 #include <utility>
 
@@ -126,7 +126,9 @@ namespace Model
      * <p>The <a>HyperParameterTuningJobConfig</a> object that describes the tuning
      * job, including the search strategy, the objective metric used to evaluate
      * training jobs, ranges of parameters to search, and resource limits for the
-     * tuning job. For more information, see <a>automatic-model-tuning</a> </p>
+     * tuning job. For more information, see <a
+     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-how-it-works.html">How
+     * Hyperparameter Tuning Works</a>.</p>
      */
     inline const HyperParameterTuningJobConfig& GetHyperParameterTuningJobConfig() const{ return m_hyperParameterTuningJobConfig; }
 
@@ -134,7 +136,9 @@ namespace Model
      * <p>The <a>HyperParameterTuningJobConfig</a> object that describes the tuning
      * job, including the search strategy, the objective metric used to evaluate
      * training jobs, ranges of parameters to search, and resource limits for the
-     * tuning job. For more information, see <a>automatic-model-tuning</a> </p>
+     * tuning job. For more information, see <a
+     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-how-it-works.html">How
+     * Hyperparameter Tuning Works</a>.</p>
      */
     inline bool HyperParameterTuningJobConfigHasBeenSet() const { return m_hyperParameterTuningJobConfigHasBeenSet; }
 
@@ -142,7 +146,9 @@ namespace Model
      * <p>The <a>HyperParameterTuningJobConfig</a> object that describes the tuning
      * job, including the search strategy, the objective metric used to evaluate
      * training jobs, ranges of parameters to search, and resource limits for the
-     * tuning job. For more information, see <a>automatic-model-tuning</a> </p>
+     * tuning job. For more information, see <a
+     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-how-it-works.html">How
+     * Hyperparameter Tuning Works</a>.</p>
      */
     inline void SetHyperParameterTuningJobConfig(const HyperParameterTuningJobConfig& value) { m_hyperParameterTuningJobConfigHasBeenSet = true; m_hyperParameterTuningJobConfig = value; }
 
@@ -150,7 +156,9 @@ namespace Model
      * <p>The <a>HyperParameterTuningJobConfig</a> object that describes the tuning
      * job, including the search strategy, the objective metric used to evaluate
      * training jobs, ranges of parameters to search, and resource limits for the
-     * tuning job. For more information, see <a>automatic-model-tuning</a> </p>
+     * tuning job. For more information, see <a
+     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-how-it-works.html">How
+     * Hyperparameter Tuning Works</a>.</p>
      */
     inline void SetHyperParameterTuningJobConfig(HyperParameterTuningJobConfig&& value) { m_hyperParameterTuningJobConfigHasBeenSet = true; m_hyperParameterTuningJobConfig = std::move(value); }
 
@@ -158,7 +166,9 @@ namespace Model
      * <p>The <a>HyperParameterTuningJobConfig</a> object that describes the tuning
      * job, including the search strategy, the objective metric used to evaluate
      * training jobs, ranges of parameters to search, and resource limits for the
-     * tuning job. For more information, see <a>automatic-model-tuning</a> </p>
+     * tuning job. For more information, see <a
+     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-how-it-works.html">How
+     * Hyperparameter Tuning Works</a>.</p>
      */
     inline CreateHyperParameterTuningJobRequest& WithHyperParameterTuningJobConfig(const HyperParameterTuningJobConfig& value) { SetHyperParameterTuningJobConfig(value); return *this;}
 
@@ -166,7 +176,9 @@ namespace Model
      * <p>The <a>HyperParameterTuningJobConfig</a> object that describes the tuning
      * job, including the search strategy, the objective metric used to evaluate
      * training jobs, ranges of parameters to search, and resource limits for the
-     * tuning job. For more information, see <a>automatic-model-tuning</a> </p>
+     * tuning job. For more information, see <a
+     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/automatic-model-tuning-how-it-works.html">How
+     * Hyperparameter Tuning Works</a>.</p>
      */
     inline CreateHyperParameterTuningJobRequest& WithHyperParameterTuningJobConfig(HyperParameterTuningJobConfig&& value) { SetHyperParameterTuningJobConfig(std::move(value)); return *this;}
 
@@ -220,6 +232,47 @@ namespace Model
     inline CreateHyperParameterTuningJobRequest& WithTrainingJobDefinition(HyperParameterTrainingJobDefinition&& value) { SetTrainingJobDefinition(std::move(value)); return *this;}
 
 
+    /**
+     * <p/>
+     */
+    inline const Aws::Vector<HyperParameterTrainingJobDefinition>& GetTrainingJobDefinitions() const{ return m_trainingJobDefinitions; }
+
+    /**
+     * <p/>
+     */
+    inline bool TrainingJobDefinitionsHasBeenSet() const { return m_trainingJobDefinitionsHasBeenSet; }
+
+    /**
+     * <p/>
+     */
+    inline void SetTrainingJobDefinitions(const Aws::Vector<HyperParameterTrainingJobDefinition>& value) { m_trainingJobDefinitionsHasBeenSet = true; m_trainingJobDefinitions = value; }
+
+    /**
+     * <p/>
+     */
+    inline void SetTrainingJobDefinitions(Aws::Vector<HyperParameterTrainingJobDefinition>&& value) { m_trainingJobDefinitionsHasBeenSet = true; m_trainingJobDefinitions = std::move(value); }
+
+    /**
+     * <p/>
+     */
+    inline CreateHyperParameterTuningJobRequest& WithTrainingJobDefinitions(const Aws::Vector<HyperParameterTrainingJobDefinition>& value) { SetTrainingJobDefinitions(value); return *this;}
+
+    /**
+     * <p/>
+     */
+    inline CreateHyperParameterTuningJobRequest& WithTrainingJobDefinitions(Aws::Vector<HyperParameterTrainingJobDefinition>&& value) { SetTrainingJobDefinitions(std::move(value)); return *this;}
+
+    /**
+     * <p/>
+     */
+    inline CreateHyperParameterTuningJobRequest& AddTrainingJobDefinitions(const HyperParameterTrainingJobDefinition& value) { m_trainingJobDefinitionsHasBeenSet = true; m_trainingJobDefinitions.push_back(value); return *this; }
+
+    /**
+     * <p/>
+     */
+    inline CreateHyperParameterTuningJobRequest& AddTrainingJobDefinitions(HyperParameterTrainingJobDefinition&& value) { m_trainingJobDefinitionsHasBeenSet = true; m_trainingJobDefinitions.push_back(std::move(value)); return *this; }
+
+
     /**
      * <p>Specifies the configuration for starting the hyperparameter tuning job using
      * one or more previous tuning jobs as a starting point. The results of previous
@@ -327,7 +380,7 @@ namespace Model
      * <p>An array of key-value pairs. You can use tags to categorize your AWS
      * resources in different ways, for example, by purpose, owner, or environment. For
      * more information, see <a
-     * href="https://docs.aws.amazon.com/https:/aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
+     * href="https://aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
      * Tagging Strategies</a>.</p> <p>Tags that you specify for the tuning job are also
      * added to all training jobs that the tuning job launches.</p>
      */
@@ -337,7 +390,7 @@ namespace Model
      * <p>An array of key-value pairs. You can use tags to categorize your AWS
      * resources in different ways, for example, by purpose, owner, or environment. For
      * more information, see <a
-     * href="https://docs.aws.amazon.com/https:/aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
+     * href="https://aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
      * Tagging Strategies</a>.</p> <p>Tags that you specify for the tuning job are also
      * added to all training jobs that the tuning job launches.</p>
      */
@@ -347,7 +400,7 @@ namespace Model
      * <p>An array of key-value pairs. You can use tags to categorize your AWS
      * resources in different ways, for example, by purpose, owner, or environment. For
      * more information, see <a
-     * href="https://docs.aws.amazon.com/https:/aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
+     * href="https://aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
      * Tagging Strategies</a>.</p> <p>Tags that you specify for the tuning job are also
      * added to all training jobs that the tuning job launches.</p>
      */
@@ -357,7 +410,7 @@ namespace Model
      * <p>An array of key-value pairs. You can use tags to categorize your AWS
      * resources in different ways, for example, by purpose, owner, or environment. For
      * more information, see <a
-     * href="https://docs.aws.amazon.com/https:/aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
+     * href="https://aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
      * Tagging Strategies</a>.</p> <p>Tags that you specify for the tuning job are also
      * added to all training jobs that the tuning job launches.</p>
      */
@@ -367,7 +420,7 @@ namespace Model
      * <p>An array of key-value pairs. You can use tags to categorize your AWS
      * resources in different ways, for example, by purpose, owner, or environment. For
      * more information, see <a
-     * href="https://docs.aws.amazon.com/https:/aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
+     * href="https://aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
      * Tagging Strategies</a>.</p> <p>Tags that you specify for the tuning job are also
      * added to all training jobs that the tuning job launches.</p>
      */
@@ -377,7 +430,7 @@ namespace Model
      * <p>An array of key-value pairs. You can use tags to categorize your AWS
      * resources in different ways, for example, by purpose, owner, or environment. For
      * more information, see <a
-     * href="https://docs.aws.amazon.com/https:/aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
+     * href="https://aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
      * Tagging Strategies</a>.</p> <p>Tags that you specify for the tuning job are also
      * added to all training jobs that the tuning job launches.</p>
      */
@@ -387,7 +440,7 @@ namespace Model
      * <p>An array of key-value pairs. You can use tags to categorize your AWS
      * resources in different ways, for example, by purpose, owner, or environment. For
      * more information, see <a
-     * href="https://docs.aws.amazon.com/https:/aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
+     * href="https://aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
      * Tagging Strategies</a>.</p> <p>Tags that you specify for the tuning job are also
      * added to all training jobs that the tuning job launches.</p>
      */
@@ -397,7 +450,7 @@ namespace Model
      * <p>An array of key-value pairs. You can use tags to categorize your AWS
      * resources in different ways, for example, by purpose, owner, or environment. For
      * more information, see <a
-     * href="https://docs.aws.amazon.com/https:/aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
+     * href="https://aws.amazon.com/answers/account-management/aws-tagging-strategies/">AWS
      * Tagging Strategies</a>.</p> <p>Tags that you specify for the tuning job are also
      * added to all training jobs that the tuning job launches.</p>
      */
@@ -414,6 +467,9 @@ namespace Model
     HyperParameterTrainingJobDefinition m_trainingJobDefinition;
     bool m_trainingJobDefinitionHasBeenSet;
 
+    Aws::Vector<HyperParameterTrainingJobDefinition> m_trainingJobDefinitions;
+    bool m_trainingJobDefinitionsHasBeenSet;
+
     HyperParameterTuningJobWarmStartConfig m_warmStartConfig;
     bool m_warmStartConfigHasBeenSet;
 
